#!/usr/bin/python3

######
## This script takes a json file of paired issues and splits it up into max. 1.000 entries.
######

import requests, json, sys, getopt
from functools import reduce

### parsing command line arguments
def getOptions(argv):
	def printUsage():
		print('test.py -f <mappingFile>')

	try:
		opts, args = getopt.getopt(argv,"hf:",["file="])
	except getopt.GetoptError as e:
		print(str(e))
		printUsage()
		sys.exit(2)

	for opt, arg in opts:
		if opt == '-h':
			printUsage()
			sys.exit()
		elif opt in ("-f", "--file"):
			mappingFile = arg
	if 'mappingFile' not in locals():
		print('mapping file is missing')
		printUsage()
		sys.exit(2)

	return mappingFile

### saves a chunk into a file
def saveChunk(chunkData, connector, fileCounter):
	print(f'saving chunk to {connector} with counter {fileCounter}')

	filename = f'chunkedMappingFile-{fileCounter}.json'
	with open(filename, 'w') as f:
		wrapperElement = {}
		wrapperElement.update({connector: chunkData})
		json.dump(wrapperElement, f, indent=4)

### splits the entries of a connector into chunks
def splitEntriesIntoChunks(connectorMappingData):
	mappingDataSize = len(connectorMappingData)
	chunkSize = 1000
	chunkIterator = 0
	connectorChunks = []
	while chunkIterator < mappingDataSize:
		connectorChunks.append(connectorMappingData[chunkIterator:min(chunkIterator + chunkSize, mappingDataSize)])
		chunkIterator += chunkSize
	print(f'split connector into {len(connectorChunks)} chunks')
	return connectorChunks

### splits the mapping file into chunks
def splitIntoChunks(mappingData):
	firstConnectorChunks = splitEntriesIntoChunks(mappingData['firstConnector'])
	secondConnectorChunks = splitEntriesIntoChunks(mappingData['secondConnector'])

	fileCounter = 1;
	for chunk in firstConnectorChunks:
		saveChunk(chunk, 'firstConnector', fileCounter)
		fileCounter += 1

	for chunk in secondConnectorChunks:
		saveChunk(chunk, 'secondConnector', fileCounter)
		fileCounter += 1


### start of script
mappingFile = getOptions(sys.argv[1:])

#parse mapping file
with open(mappingFile) as f:
    mappingData = json.load(f)

splitIntoChunks(mappingData)